@@ -23,7 +23,7 @@ GravatarDownloadPixmapWidget::GravatarDownloadPixmapWidget(QWidget *parent)
     auto mainLayout = new QVBoxLayout(this);
     auto hbox = new QHBoxLayout;
     mainLayout->addLayout(hbox);
-    auto lab = new QLabel(i18n("Email:"));
+    auto lab = new QLabel(i18nc("@label:textbox", "Email:"));
     lab->setObjectName("labemail"_L1);
     hbox->addWidget(lab);
     mLineEdit = new QLineEdit;
@@ -39,7 +39,7 @@ GravatarDownloadPixmapWidget::GravatarDownloadPixmapWidget(QWidget *parent)
     mFallbackGravatar->setObjectName("fallbackgravatar"_L1);
     mainLayout->addWidget(mFallbackGravatar);
 
-    mGetPixmapButton = new QPushButton(i18n("&Search"));
+    mGetPixmapButton = new QPushButton(i18nc("@action:button", "&Search"));
     mGetPixmapButton->setObjectName("searchbutton"_L1);
     connect(mGetPixmapButton, &QAbstractButton::clicked, this, &GravatarDownloadPixmapWidget::slotSearchButton);
     hbox->addWidget(mGetPixmapButton);
